@@ -8,7 +8,7 @@
 #include "tausolver.h"
 #include "nsintegrator.h"
 
-#include "helperfuncs.h"
+//#include "helperfuncs.h"
 
 int main() {
 
@@ -64,7 +64,6 @@ int main() {
   u.addPerturbations(kxmax,kzmax,perturbMag,decay);
   //FlowField u("u80");
   //FlowField q("q80");
-  cout << "div(u)/L2Norm(u)  == " << u.divergence()/L2Norm(u) << endl;  
   
   FlowField omega(Nx,Ny,Nz,3,Lx,Lz,a,b);
 
@@ -93,13 +92,14 @@ int main() {
   
   for (Real t=T0; t<=T1; t += dT) {
     cout << "===============================================" << endl;
-    cout << "         t == " << t << endl;
-    cout << "        dt == " << dt << endl;
-    cout << "       CFL == " << dns.CFL() << endl;
-    cout << "L2Norm2(u) == " << L2Norm2(u) << endl;
-    cout << "     Ubulk == " << dns.Ubulk() << endl;
-    cout << "     ubulk == " << Re(u.profile(0,0,0)).mean()/2 << endl;
-    cout << "      dPdx == " << dns.dPdx() << endl;
+    cout << "          t == " << t << endl;
+    cout << "         dt == " << dt << endl;
+    cout << "        CFL == " << dns.CFL() << endl;
+    cout << " L2Norm2(u) == " << L2Norm2(u) << endl;
+    cout << "divNorm2(u) == " << divNorm(u)/L2Norm(u) << endl;  
+    cout << "      Ubulk == " << dns.Ubulk() << endl;
+    cout << "      ubulk == " << Re(u.profile(0,0,0)).mean()/2 << endl;
+    cout << "       dPdx == " << dns.dPdx() << endl;
     
 
     if (int(t) % 40 == 0 && t != T0) {
@@ -110,25 +110,23 @@ int main() {
     }
 
     u.makePhysical();
-    u.saveSliceXY(0,0,"uside");
-    u.saveSliceXY(0,1,"vside");
-    u.saveSliceXY(0,2,"wside");
-    u.saveSliceXY(0,2,"wside");
-    u.saveCrossSection(0,0,"usec");
-    u.saveCrossSection(0,1,"vsec");
-    u.saveCrossSection(0,2,"wsec");
+    u.saveSlice(2,0,0,"uside");
+    u.saveSlice(2,1,0,"vside");
+    u.saveSlice(2,2,0,"wside");
+    u.saveSlice(0,0,0,"usec");
+    u.saveSlice(0,1,0,"vsec");
+    u.saveSlice(0,2,0,"wsec");
     u.makeSpectral();
 
-    u.vorticity2(omega);
-    omega.saveCrossSection(0,0,"omsec0");
-    omega.saveCrossSection(0,1,"omsec1");
-    omega.saveCrossSection(0,2,"omsec2");
-
+    curl(u, omega);
+    omega.saveSlice(0,0,0,"omsec0");
+    omega.saveSlice(0,1,0,"omsec1");
+    omega.saveSlice(0,2,0,"omsec2");
     for (int kx=-kxmax; kx<=kxmax; ++kx) {
-      int nx = u.nx(kx);
+      int mx = u.mx(kx);
       for (int kz=0; kz<=kzmax; ++kz) {
-	int nz = u.nz(kz);
-	BasisFunc u_kxkz = u.profile(nx,nz);
+	int mz = u.mz(kz);
+	BasisFunc u_kxkz = u.profile(mx,mz);
 	modestream << L2Norm(u_kxkz) << sp;
       }
     }
