@@ -168,21 +168,23 @@ int main() {
     }
 
     for (int kx=-2; kx<=2; ++kx) {
+      int mx = ul.mx(kx);
       for (int kz=-2; kz<=2; ++kz) {
-      ul.saveProfile(ul.nx(kx), ul.nz(kz), string("ul")+i2s(kx)+i2s(kz), trans);
-      un.saveProfile(un.nx(kx), ul.nz(kz), string("un")+i2s(kx)+i2s(kz), trans);
+	int mz = ul.mz(kz);
+	ul.saveProfile(mx, mz, string("ul")+i2s(kx)+i2s(kz), trans);
+	un.saveProfile(mx, mz, string("un")+i2s(kx)+i2s(kz), trans);
       
-      //pl.saveProfile(pl.nx(kx), pl.nz(kz), string("pl")+i2s(kx)+i2s(kz), trans);
-      //pn.saveProfile(pn.nx(kx), pn.nz(kz), string("pn")+i2s(kx)+i2s(kz), trans);
+        //pl.saveProfile(mx, mz, string("pl")+i2s(kx)+i2s(kz), trans);
+        //pn.saveProfile(mx, mz, string("pn")+i2s(kx)+i2s(kz), trans);
 
-      // Extract the 0-component of kx,kz pressure profile, transform, and save
-      ComplexChebyCoeff pn_profile = pn.profile(pn.nx(kx), pn.nz(kz), 0);
-      pn_profile.makePhysical(trans);
-      pn_profile.save(string("pn")+i2s(kx)+i2s(kz));
+        // Extract the 0-component of kx,kz p profile, transform, and save
+	ComplexChebyCoeff pn_profile = pn.profile(mx, mz, 0);
+	pn_profile.makePhysical(trans);
+	pn_profile.save(string("pn")+i2s(kx)+i2s(kz));
       }
     }
     cout << "CFL == " << CFL << endl;
-    cout << "div(un)/L2Norm(un) == " << un.divergence()/L2Norm(un) << endl;
+    cout << "divNorm(un)/L2Norm(un)    == " << divNorm(un)/L2Norm(un) << endl;
     cout << "L2Norm(un)/L2Norm(uPoiss) == " << unnorm/uPoissNorm << endl;
     cout << "L2Norm(ul)/L2Norm(uPoiss) == " << ulnorm/uPoissNorm << endl;
     cout << "L2Dist(un,ul)/L2Norm(ul)  == " << L2Dist(un, ul)/ulnorm <<endl;
