@@ -88,7 +88,7 @@ int main() {
   cout << "Initial data, prior to time stepping" << endl;
   cout << "L2Norm(un)  == " << L2Norm(un) << endl;
   cout << "L2Norm(Pn)  == " << L2Norm(Pn) << endl;
-  cout << "div(un)     == " << un.divergence() << endl;  
+  cout << "divNorm(un) == " << divNorm(un) << endl;  
   cout << endl;
   NSIntegrator dns(un, Ubase, nu, dt, flags);
 
