@@ -385,7 +385,7 @@ inline Real FlowField::x(int nx) const {
 }
 inline Real FlowField::y(int ny) const {
   //assert(ystate_ == Physical);
-  return cos(pi*ny/(Ny_-1));
+  return 0.5*((b_+a_) + (b_-a_)*cos(pi*ny/(Ny_-1)));
 }
 inline Real FlowField::z(int nz) const {
   //assert(zstate_ == Physical);
