@@ -181,8 +181,7 @@ void BasisFunc::save(const string& filebase) const {
   ofstream os(filename.c_str());
   os << setprecision(REAL_DIGITS);
   char s=' ';
-  //if (MATLABVERSION > 4)
-    os << '%'
+  os << '%'
      <<s<< Ny_
      <<s<< kx_
      <<s<< kz_
@@ -872,7 +871,8 @@ ComplexChebyCoeff dot(const BasisFunc& f_, const BasisFunc& g_) {
   BasisFunc& g = (BasisFunc&) g_;
   assert(f.geometryCongruent(g));
   int Ny= f.Ny();
-  fieldstate entrystate = f.state();
+  fieldstate fstate = f.state();
+  fieldstate gstate = g.state();
   ChebyTransform t(Ny);
   f.makePhysical(t);
   g.makePhysical(t);
@@ -881,11 +881,10 @@ ComplexChebyCoeff dot(const BasisFunc& f_, const BasisFunc& g_) {
   for (int ny=0; ny<Ny; ++ny)
     fg.set(ny, f[0][ny]*g[0][ny] + f[1][ny]*g[1][ny] + f[2][ny]*g[2][ny]);
 
-  if (entrystate==Spectral) {
-    f.makeSpectral(t);
-    g.makeSpectral(t);
-    fg.makeSpectral(t);
-  }
+  
+  f.makeState(fstate,t);
+  g.makeState(gstate,t);
+  fg.makeState(fstate, t);
   return fg;
 }
 	   
