@@ -880,9 +880,9 @@ void navierstokesNL(const FlowField& u,const ChebyCoeff& U, FlowField& f,
     break;
   case Alternating: 
     divergenceNL(u,U,f,tmp); 
-    method = _Alternating;
+    method = Alternating_;
     break;
-  case _Alternating: 
+  case Alternating_: 
     convectionNL(u,U,f,tmp); 
     method = Alternating;
     break;
@@ -948,8 +948,8 @@ void rotationalNL(const FlowField& u_, const ChebyCoeff& U_, FlowField& f,
   int Mz = u.Mz();
 
   for (int ny=0; ny<My; ++ny) { 
-    Real _U  = U[ny];
-    Real _Uy = Uy[ny];
+    Real rU  = U[ny];
+    Real rUy = Uy[ny];
     for (int mx=0; mx<Mx; ++mx) {
       Complex d_dx(0.0, 2*pi*u.kx(mx)/u.Lx());
       for (int mz=0; mz<Mz; ++mz) {
@@ -957,9 +957,9 @@ void rotationalNL(const FlowField& u_, const ChebyCoeff& U_, FlowField& f,
 	vc = u.cmplx(mx,ny,mz, 1);
 	wc = u.cmplx(mx,ny,mz, 2);
 
-	f.cmplx(mx,ny,mz, 0) = _U*d_dx*uc + vc*_Uy;
-	f.cmplx(mx,ny,mz, 1) = _U*d_dx*vc;  
-	f.cmplx(mx,ny,mz, 2) = _U*d_dx*wc;
+	f.cmplx(mx,ny,mz, 0) = rU*d_dx*uc + vc*rUy;
+	f.cmplx(mx,ny,mz, 1) = rU*d_dx*vc;  
+	f.cmplx(mx,ny,mz, 2) = rU*d_dx*wc;
       }
     }
   }
@@ -975,9 +975,9 @@ void rotationalNL(const FlowField& u_, const ChebyCoeff& U_, FlowField& f,
   Real omega_x;
   Real omega_y;
   Real omega_z;
-  Real _u;
-  Real _v;
-  Real _w;
+  Real ru;
+  Real rv;
+  Real rw;
 
   // Loop should be efficient if we get 9 cache lines. 
   // Add in omega x u so that 
@@ -986,16 +986,16 @@ void rotationalNL(const FlowField& u_, const ChebyCoeff& U_, FlowField& f,
     //Real Uy = Ubasey[ny];
     for (int nx=0; nx<Nx; ++nx) {
       for (int nz=0; nz<Nz; ++nz) {
-	_u = u(nx,ny,nz, 0);
-	_v = u(nx,ny,nz, 1);
-	_w = u(nx,ny,nz, 2);
+	ru = u(nx,ny,nz, 0);
+	rv = u(nx,ny,nz, 1);
+	rw = u(nx,ny,nz, 2);
 	omega_x = vort(nx,ny,nz, 0);
 	omega_y = vort(nx,ny,nz, 1);
 	omega_z = vort(nx,ny,nz, 2);
 
-	f(nx,ny,nz, 0) += omega_y*_w - omega_z*_v;
-	f(nx,ny,nz, 1) += omega_z*_u - omega_x*_w;
-	f(nx,ny,nz, 2) += omega_x*_v - omega_y*_u;
+	f(nx,ny,nz, 0) += omega_y*rw - omega_z*rv;
+	f(nx,ny,nz, 1) += omega_z*ru - omega_x*rw;
+	f(nx,ny,nz, 2) += omega_x*rv - omega_y*ru;
       }
     }
   }
@@ -1260,9 +1260,9 @@ void linearizedNL(const FlowField& u_, const ChebyCoeff& U_, FlowField& f) {
   U.makePhysical(trans);
   Uy.makePhysical(trans);
 
-  Complex _u;
-  Complex _v;
-  Complex _w;
+  Complex cu;
+  Complex cv;
+  Complex cw;
 
   int Mx = u.Mx();
   int Ny = u.Ny();
@@ -1275,13 +1275,13 @@ void linearizedNL(const FlowField& u_, const ChebyCoeff& U_, FlowField& f) {
     for (int mx=0; mx<Mx; ++mx) {
       Complex d_dx(0.0, ax*u.kx(mx));
       for (int mz=0; mz<Mz; ++mz) {
-	_u = u.cmplx(mx,ny,mz, 0);
-	_v = u.cmplx(mx,ny,mz, 1);
-	_w = u.cmplx(mx,ny,mz, 2);
+	cu = u.cmplx(mx,ny,mz, 0);
+	cv = u.cmplx(mx,ny,mz, 1);
+	cw = u.cmplx(mx,ny,mz, 2);
 
-	f.cmplx(mx,ny,mz, 0) = U[ny]*d_dx*_u + _v*Uy[ny];
-	f.cmplx(mx,ny,mz, 1) = U[ny]*d_dx*_v;  
-	f.cmplx(mx,ny,mz, 2) = U[ny]*d_dx*_w;
+	f.cmplx(mx,ny,mz, 0) = U[ny]*d_dx*cu + cv*Uy[ny];
+	f.cmplx(mx,ny,mz, 1) = U[ny]*d_dx*cv;  
+	f.cmplx(mx,ny,mz, 2) = U[ny]*d_dx*cw;
       }
     }
 
@@ -1334,7 +1334,7 @@ void up2q(const FlowField& u_, const FlowField& p, FlowField& q,
   assert(p.Nd() == 1);
 
   q = p;
-  if (nonl_method == Rotational)
+  if (nonl_method != Rotational)
     return;
 
   FlowField& u = (FlowField&) u_;
@@ -1361,6 +1361,23 @@ void up2q(const FlowField& u_, const FlowField& p, FlowField& q,
   return;
 }
 
+ostream& operator<<(ostream& os, NonlinearMethod nonl) {
+  string s;
+  switch(nonl) {
+  case Rotational: s="Rotational"; break;
+  case Convection: s="Convection"; break;
+  case Divergence: s="Divergence"; break;
+  case SkewSymmetric: s="SkewSymmetric"; break;
+  case Alternating: s="Alternating"; break;
+  case Alternating_: s="Alternating_"; break;
+  case Linearized: s="Linearized"; break;
+  default: s = "Invalid NonlinearMethod: please submit bug report";
+  }
+  os << s;
+  return os;
+}
+
+
 /**************************************************************************
 void calc_dedt(const FlowField& u, const ChebyCoeff& U, const FlowField& p, 
 	       Real dPdx, Real nu, FlowField& dedt, FlowField& tmp3d_a, 
