@@ -224,8 +224,11 @@ Vector FlowField::xgridpts() const {
 }
 Vector FlowField::ygridpts() const {
   Vector ypts(Ny_);
+  Real c = 0.5*(b_+a_);
+  Real r = 0.5*(b_-a_);
+  Real piN = pi/(Ny_-1);
   for (int ny=0; ny<Ny_; ++ny)
-    ypts[ny] = y(ny);
+    ypts[ny] = c + r*cos(piN*ny);
   return ypts;
 }
 Vector FlowField::zgridpts() const {
@@ -512,32 +515,32 @@ void FlowField::addProfile(const ChebyCoeff& profile, int i) {
   assert(ystate_ == profile.state());
   int kx=0;
   int kz=0;
-  int _mx = mx(kx);
-  int _mz = mz(kz);
+  int m_x = mx(kx);
+  int m_z = mz(kz);
   for (int ny=0; ny<Ny_; ++ny) 
-    cmplx(_mx, ny, _mz, i) += Complex(profile[ny], 0.0);
+    cmplx(m_x, ny, m_z, i) += Complex(profile[ny], 0.0);
 }
 
 void FlowField::addProfile(const ComplexChebyCoeff& profile, 
-			   int _mx, int _mz, int i, bool addconj) {
+			   int m_x, int m_z, int i, bool addconj) {
   assert(xzstate_== Spectral);
   assert(ystate_ == profile.state());
-  int _kx = kx(_mx);
-  int _kz = kz(_mz);
+  int k_x = kx(m_x);
+  int k_z = kz(m_z);
   for (int ny=0; ny<Ny_; ++ny) 
-    cmplx(_mx, ny, _mz, i) += profile[ny];
-  if (addconj && _kx !=0 && _kz ==0) {
-    _mx = mx(-_kx);
+    cmplx(m_x, ny, m_z, i) += profile[ny];
+  if (addconj && k_x !=0 && k_z ==0) {
+    m_x = mx(-k_x);
     for (int ny=0; ny<Ny_; ++ny) 
-      cmplx(_mx,ny,_mz, i) += conjugate(profile[ny]);
+      cmplx(m_x,ny,m_z, i) += conjugate(profile[ny]);
   }
 }
 
 BasisFunc FlowField::profile(int mx, int mz) const {
   assert(xzstate_== Spectral);
-  int _kx = kx(mx);
-  int _kz = kz(mz);
-  BasisFunc rtn(Ny_, _kx, _kz, Lx_, Lz_, a_, b_, ystate_);
+  int k_x = kx(mx);
+  int k_z = kz(mz);
+  BasisFunc rtn(Ny_, k_x, k_z, Lx_, Lz_, a_, b_, ystate_);
   
   int Nd = lesser(Nd_, 3);
   for (int i=0; i<Nd; ++i)
@@ -550,17 +553,17 @@ void FlowField::addProfile(const BasisFunc& profile, bool addconj) {
   assert(xzstate_== Spectral);
   assert(ystate_ == profile.state());
   assert(Nd_ == 3);
-  int _mx = mx(profile.kx());
-  int _mz = mz(profile.kz());
+  int m_x = mx(profile.kx());
+  int m_z = mz(profile.kz());
   for (int i=0; i<Nd_; ++i)
     for (int ny=0; ny<Ny_; ++ny) 
-      cmplx(_mx, ny, _mz, i) += profile[i][ny];
+      cmplx(m_x, ny, m_z, i) += profile[i][ny];
 
   if (addconj && profile.kx() !=0 && profile.kz() ==0) {
-    _mx = mx(-profile.kx());
+    m_x = mx(-profile.kx());
     for (int i=0; i<Nd_; ++i)
       for (int ny=0; ny<Ny_; ++ny) 
-	cmplx(_mx, ny, _mz, i) += conjugate(profile[i][ny]);
+	cmplx(m_x, ny, m_z, i) += conjugate(profile[i][ny]);
   }
 }
 
@@ -851,21 +854,21 @@ void FlowField::addPerturbation(int kx, int kz, Real mag, Real decay) {
   ComplexChebyCoeff v(Ny_, a_, b_, Spectral);
   ComplexChebyCoeff w(Ny_, a_, b_, Spectral);
   randomProfile(u,v,w, kx, kz, Lx_, Lz_, mag, decay);
-  int _mx = mx(kx);
-  int _mz = mz(kz);
+  int m_x = mx(kx);
+  int m_z = mz(kz);
   for (int ny=0; ny<Ny_; ++ny) {
-    cmplx(_mx, ny, _mz, 0) += u[ny];
-    cmplx(_mx, ny, _mz, 1) += v[ny];
-    cmplx(_mx, ny, _mz, 2) += w[ny];
+    cmplx(m_x, ny, m_z, 0) += u[ny];
+    cmplx(m_x, ny, m_z, 1) += v[ny];
+    cmplx(m_x, ny, m_z, 2) += w[ny];
   }
   if (kz==0 && kx!=0) {
-    int _mx = mx(-kx);
-    int _mz = mz(0); // -kz=0
+    int m_x = mx(-kx);
+    int m_z = mz(0); // -kz=0
     for (int i=0; i<Nd_; ++i)
       for (int ny=0; ny<Ny_; ++ny) {
-	cmplx(_mx, ny, _mz, 0) += conjugate(u[ny]);
-	cmplx(_mx, ny, _mz, 1) += conjugate(v[ny]);
-	cmplx(_mx, ny, _mz, 2) += conjugate(w[ny]);
+	cmplx(m_x, ny, m_z, 0) += conjugate(u[ny]);
+	cmplx(m_x, ny, m_z, 1) += conjugate(v[ny]);
+	cmplx(m_x, ny, m_z, 2) += conjugate(w[ny]);
       }
   }
   return;
@@ -1073,12 +1076,12 @@ void FlowField::saveSpectrum(const string& filebase) const {
 
   assert(xzstate_ == Spectral && ystate_ == Spectral);
  
-  int _Mx = Mx();
-  int _Mz = Mz();
+  int M_x = Mx();
+  int M_z = Mz();
   ComplexChebyCoeff u(Ny_,a_,b_,Spectral);
 
-  for (int mx=0; mx<_Mx; ++mx) {
-    for (int mz=0; mz<_Mz; ++mz) {
+  for (int mx=0; mx<M_x; ++mx) {
+    for (int mz=0; mz<M_z; ++mz) {
       Real e = 0.0;
       for (int i=0; i<Nd_; ++i) {
 	for (int ny=0; ny<Ny_; ++ny) 
@@ -1644,7 +1647,7 @@ Vector vectorL1Dist(const FlowField& u, const FlowField& v) {
     for (int ny=0; ny<u.numYmodes(); ++ny) 
       for (int nx=0; nx<u.numXmodes(); ++nx) 
 	for (int nz=0; nz<u.numZmodes(); ++nz) 
-	  sum[i] += norm(u.cmplx(nx,ny,nz,i)-v.cmplx(nx,ny,nz,i));
+	  sum[i] += true_norm(u.cmplx(nx,ny,nz,i)-v.cmplx(nx,ny,nz,i));
   cferror("L1Norm(const FlowField& u) : u must be pure spectral or pure physical");
   return sum;
 }
@@ -1694,8 +1697,8 @@ void randomUprofile(ComplexChebyCoeff& u, Real mag, Real decay) {
   //cout << "after random u(a) == " << u.eval_a() << endl;
   //cout << "after random u(b) == " << u.eval_b() << endl;
 
-  assert(norm(u.eval_b()) < EPSILON);
-  assert(norm(u.eval_a()) < EPSILON);
+  assert(true_norm(u.eval_b()) < EPSILON);
+  assert(true_norm(u.eval_a()) < EPSILON);
 }
 
 void randomVprofile(ComplexChebyCoeff& v, Real mag, Real decay) {
@@ -1779,8 +1782,8 @@ void chebyUprofile(ComplexChebyCoeff& u, int n, Real decay) {
   u.sub(1, u1);
   //cout << "random u(a) == " << u.eval_a() << endl;
   //cout << "random u(b) == " << u.eval_b() << endl;
-  assert(norm(u.eval_b()) < EPSILON);
-  assert(norm(u.eval_a()) < EPSILON);
+  assert(true_norm(u.eval_b()) < EPSILON);
+  assert(true_norm(u.eval_a()) < EPSILON);
 }
 
 void chebyVprofile(ComplexChebyCoeff& v, int n, Real decay) {
@@ -1937,9 +1940,9 @@ void randomProfile(ComplexChebyCoeff& u, ComplexChebyCoeff& v, ComplexChebyCoeff
   div += wz;
 
   Real divNorm = L2Norm(div);
-  Real ubcNorm = norm(u.eval_a()) + norm(u.eval_b());
-  Real vbcNorm = norm(v.eval_a()) + norm(v.eval_b());
-  Real wbcNorm = norm(w.eval_a()) + norm(w.eval_b());
+  Real ubcNorm = true_norm(u.eval_a()) + true_norm(u.eval_b());
+  Real vbcNorm = true_norm(v.eval_a()) + true_norm(v.eval_b());
+  Real wbcNorm = true_norm(w.eval_a()) + true_norm(w.eval_b());
   assert(divNorm < EPSILON);
   assert(ubcNorm < EPSILON);
   assert(vbcNorm < EPSILON);
@@ -2041,9 +2044,9 @@ void chebyProfile(ComplexChebyCoeff& u, ComplexChebyCoeff& v, ComplexChebyCoeff&
   div += wz;
 
   Real divNorm = L2Norm(div);
-  Real ubcNorm = norm(u.eval_a()) + norm(u.eval_b());
-  Real vbcNorm = norm(v.eval_a()) + norm(v.eval_b());
-  Real wbcNorm = norm(w.eval_a()) + norm(w.eval_b());
+  Real ubcNorm = true_norm(u.eval_a()) + true_norm(u.eval_b());
+  Real vbcNorm = true_norm(v.eval_a()) + true_norm(v.eval_b());
+  Real wbcNorm = true_norm(w.eval_a()) + true_norm(w.eval_b());
   assert(divNorm < EPSILON);
   assert(ubcNorm < EPSILON);
   assert(vbcNorm < EPSILON);
@@ -3011,8 +3014,8 @@ Real FlowField::divergence(bool normalize) const {
       for (int ny=Nym-1; ny>=0; --ny) {
 	Complex ux = cx*kx_*cmplx(nx,ny,nz,0);
 	Complex wz = cz*kz_*cmplx(nx,ny,nz,2);
-	subdiv += norm(ux + vy[ny] + wz);
-	subdivnorm += norm(ux) + norm(vy[ny]) + norm(wz);
+	subdiv += true_norm(ux + vy[ny] + wz);
+	subdivnorm += true_norm(ux) + true_norm(vy[ny]) + true_norm(wz);
       }
       div += subdiv;
       divnorm += subdivnorm;
