@@ -74,49 +74,6 @@ bool isPowerOfTwo (int N) {
   return true;
 }
 
-/****************
-Real pow (Real x, int n) {
-  if (n < 0) {
-    x = 1.0 / x;
-    n = -n;
-  }
-  switch (n) {
-  case 0:
-    return 1;
-  case 1:
-    return x;
-  case 2:
-    return x * x;
-  case 3:
-    return x * x * x;
-  case 4:{
-    Real xx = x * x;
-    return xx * xx;
-  }
-  case 5:{
-    Real xx = x * x;
-    return x * xx * xx;
-  }
-  case 6:{
-    Real xx = x * x;
-    return xx * xx * xx;
-  }
-  case 7:{
-    Real xxx = x * x * x;
-    return xxx * xxx * x;
-  }
-  case 8:{
-    Real xx = x * x;
-    Real xxxx = xx * xx;
-    return xxxx * xxxx;
-  }
-  default:{
-    int m = n / 2;
-    return pow (x, m) * pow (x, n - m);	// I can't remember the while() algorithm.
-  }
-  }
-}
-***************************************/
 int pow (int x, int n) {
   if (n < 0)
     cferror
@@ -130,36 +87,28 @@ int pow (int x, int n) {
     return x * x;
   case 3:
     return x * x * x;
-  case 4:{
+  case 4: {
     int xx = x * x;
     return xx * xx;
   }
-  case 5:{
-    int xx = x * x;
-    return x * xx * xx;
-  }
-  case 6:{
-    int xx = x * x;
-    return xx * xx * xx;
-  }
-  case 7:{
-    int xxx = x * x * x;
-    return xxx * xxx * x;
-  }
-  case 8:{
-    int xx = x * x;
-    int xxxx = xx * xx;
-    return xxxx * xxxx;
-  }
-  default:{
-    if ((n % 2) == 0)
-      return square(pow(x,n/2));
-    else 
-      return x*pow(x,n-1);
+  default: {
+    // a*x^n is invariant and n is decreasing in this loop
+    int a = 1; 
+    while (n>0) {
+      if (n%2 == 0) {
+	x *= x; // x -> x^2
+	n /= 2; // n -> n/2
+      }
+      else {
+	a *= x; // a -> ax
+	--n;    // n -> n-1
+      }
+    }
+    return a;
   }
   }
-}
-
+}      
+	  
 void save (Complex c, const string & filebase) {
   string extension (".cmplx");
   string filename = filebase + extension;
@@ -308,14 +257,3 @@ istream & operator >> (istream & is, fieldstate & f) {
   return is;
 }
 
-void alwaysAssert_fail (const char *__assertion, const char *__file,
-			unsigned int __line, const char *__function) {
-  cerr << "Assertion failed: " << __assertion << " in function " <<
-    __function << endl;
-  cerr << "file " << __file << " line " << __line << endl;
-  abort ();
-}
-
-void assertfail () {
-  cout << "Assertion failed. " << endl;
-}
