@@ -40,9 +40,7 @@ enum fieldstate { Physical, Spectral };
 enum parity { Even, Odd };
 
 const int REAL_DIGITS = 17;
-const int MATLABVERSION = 5;
-const Real LOG2 = log (2.0);
-const Complex I (0.0, 1.0);
+const Complex I(0.0, 1.0);
 
 #ifdef WIN32
 const Real pi = 3.14159265358979323846;
@@ -52,90 +50,98 @@ const Real pi = M_PI;
 
 string i2s (int n);
 
-void cferror (const string & message);
+void cferror(const string & message);
 void cfpause();
 
 inline int kronecker(int m, int n) {return (m==n)? 1 : 0;}
 
 //inline Real abs(Real x) {return fabs(x);}
-inline Real log2 (Real x) {
-  return log (x) / LOG2;
-}
-inline Real square (Real x) {
+inline Real square(Real x) {
   return x * x;
 }
-inline Real cube (Real x) {
+inline Real cube(Real x) {
   return x * x * x;
 }
-inline Real nr_sign (Real a, Real b) {
+inline Real nr_sign(Real a, Real b) {
   return (b >= 0.0) ? fabs (a) : -fabs (a);
 }
 
-inline int square (int x) {
+inline int square(int x) {
   return x * x;
 }
-inline int cube (int x) {
+inline int cube(int x) {
   return x * x * x;
 }
-inline void swap (int &a, int &b) {
+inline void swap(int& a, int& b) {
   int tmp = a;
   a = b;
   b = tmp;
 }
-inline void swap (Real & a, Real & b) {
+inline void swap(Real& a, Real& b) {
   Real tmp = a;
   a = b;
   b = tmp;
 }
+inline void swap(Complex& a, Complex& b) {
+  Complex tmp = a;
+  a = b;
+  b = tmp;
+}
 
 // Inline replacements for >? and <? GNUisms.
-inline int Greater (int a, int b) {
+inline int Greater(int a, int b) {
   return (a > b) ? a : b;
 }
-inline int lesser (int a, int b) {
+inline int lesser(int a, int b) {
   return (a < b) ? a : b;
 }
-inline Real Greater (Real a, Real b) {
+inline Real Greater(Real a, Real b) {
   return (a > b) ? a : b;
 }
-inline Real lesser (Real a, Real b) {
+inline Real lesser(Real a, Real b) {
   return (a < b) ? a : b;
 }
 
 //Real pow (Real x, int n);
-int pow (int n, int p);
+int pow(int n, int p);
 
-Real pythag (Real a, Real b);	// sqrt(a^2 + b^2) avoiding over/underflow
-bool isPowerOfTwo (int n);
+Real pythag(Real a, Real b);	// sqrt(a^2 + b^2) avoiding over/underflow
+bool isPowerOfTwo(int n);
 
-void save (Real c, const string & filebase);
-void load (Real & c, const string & filebase);
-void save (Complex c, const string & filebase);
-void load (Complex & c, const string & filebase);
+void save(Real c, const string& filebase);
+void load(Real& c, const string& filebase);
+void save(Complex c, const string& filebase);
+void load(Complex& c, const string& filebase);
 
-void write (ostream & os, Complex z);
-void write (ostream & os, Real x);
-void write (ostream & os, int n);
-void write (ostream & os, bool b);
-void write (ostream & os, fieldstate s);
+void write(ostream& os, Complex z);
+void write(ostream& os, Real x);
+void write(ostream& os, int n);
+void write(ostream& os, bool b);
+void write(ostream& os, fieldstate s);
 
-void read (istream & is, Complex & z);
-void read (istream & is, Real & x);
-void read (istream & is, int &n);
-void read (istream & is, bool &b);
-void read (istream & os, fieldstate & s);
+void read(istream& is, Complex& z);
+void read(istream& is, Real& x);
+void read(istream& is, int& n);
+void read(istream& is, bool& b);
+void read(istream& os, fieldstate& s);
 
-inline Real Re (const Complex & z) {
-  return z.real ();
+inline Real Re(const Complex& z) {
+  return z.real();
 }
-inline Real Im (const Complex & z) {
-  return z.imag ();
+inline Real Im(const Complex& z) {
+  return z.imag();
 }
-inline Complex conjugate (Complex z) {
-  return Re (z) - I * Im (z);
+inline Complex conjugate(const Complex& z) {
+  return Complex(Re(z), -Im(z));
 }
-inline Real norm2 (const Complex& z) {
-  return square (Re (z)) + square (Im (z));
+
+// Beware the standard-library norm(complex) function! It returns the
+// squared norm!
+inline Real true_norm(const Complex& z) {
+  return pythag(Re(z), Im(z));
+}
+inline Real norm2(const Complex& z) {
+  return square(Re(z)) + square(Im(z));
 }
 
 // The following functions are defined in complexdefs.h, but not here, in
@@ -154,30 +160,9 @@ ostream & operator << (ostream & os, Complex z);
 ostream & operator << (ostream & os, fieldstate f);
 istream & operator >> (istream & is, fieldstate & f);
 
-void alwaysAssert_fail (const char *__assertion, const char *__file,
-			unsigned int __line, const char *__function);
-
-void assertfail ();
-
-#ifdef WIN32
-#undef assert
-#define assert(expr) (if(!expr) {cout << "Assertion failed. "<<endl; abort();})
-#define alwaysAssert(expr) (assert(expr))
-#else				/* not WIN32 */
-#define alwaysAssert(expr)						      \
-  ((void) ((expr) ? 0 :							      \
-	   (alwaysAssert_fail (__STRING(expr),				      \
-			   __FILE__, __LINE__, __ASSERT_FUNCTION), 0)))
-
-# if defined __cplusplus ? __GNUC_PREREQ (2, 6) : __GNUC_PREREQ (2, 4)
-#   define __ASSERT_FUNCTION	__PRETTY_FUNCTION__
-# else
-#  if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
-#   define __ASSERT_FUNCTION	__func__
-#  else
-#   define __ASSERT_FUNCTION	((__const char *) 0)
-#  endif
-# endif
-#endif				/* not WIN32 */
+//#ifdef WIN32
+//#undef assert
+//#define assert(expr) (if(!expr) {cout << "Assertion failed. "<<endl; abort();})
+//#endif
 
 #endif				/* MATHDEFS_H */
