@@ -46,27 +46,50 @@ TimeStep::TimeStep(Real dt, Real dtmin, Real dtmax, Real dT,
   assert(dt>0 && dt<=dT);
   assert(dt>=dtmin && dt<=dtmax);
   assert(n_>=nmin_ &&  n_<=nmax_);
+  assert(nmin_ > 0);
 }
 
+
+// relations
+// n*dt = dT
+// 
 bool TimeStep::adjust(Real CFL) {
   CFL_ = CFL;
-  int new_n = n_;
-  if (CFL<CFLmin_ || CFL>CFLmax_) {
-    Real CFLtarget = 0.5*(CFLmin_ + CFLmax_);
-    new_n = int(n_*CFL/CFLtarget);
-    if (new_n < nmin_) {
-      cerr << "TimeStep::adjust(CFL) : topping out at dt==" << dT_/nmin_<<endl;
-      new_n = nmin_;
-    }
-    if (new_n > nmax_) {
-      cerr << "TimeStep::adjust(CFL) : bottoming out at dt=="<<dT_/nmax_<<endl;
-      new_n = nmax_;
-    }
+  if (CFLmin_ <= CFL && CFL <= CFLmax_)
+    return false;
+  
+  // potential new value of n.
+  int n = n_;   
+
+  // decrease CFL by increasing n, decreasing dt = T/n
+  // CFL' == CFL * dt'/dt == n/n' == n/(n+1);
+  while (CFL > CFLmax_ && n < nmax_) 
+    CFL *= Real(n)/Real(++n);
+
+  // increase CFL by decreasing n, increasing dt = T/n
+  while (CFL < CFLmin_ && n > nmin_) 
+    CFL *= Real(n)/Real(--n);
+
+  // Assure that that dtmin <= dt <= dtmax, roughly, by 
+  // resetting n s.t.  nmin <=  n <= nmax
+  if (n < nmin_) {
+    cerr << "TimeStep::adjust(CFL) : topping out at dt==" << dT_/nmin_<<endl;
+    n = nmin_;
+    
   }
-  bool adjustment = (new_n == n_) ? false : true;
+  else if (n > nmax_) {
+    cerr << "TimeStep::adjust(CFL) : bottoming out at dt=="<<dT_/nmax_<<endl;
+    n = nmax_;
+  }
+  bool adjustment = (n == n_) ? false : true;
   if (adjustment) {
-    CFL_ *= Real(n_)/Real(new_n);  // i.e. *= (new dt)/(old dt)
-    n_ = new_n;
+    cerr << "TimeStep::adjust(CFL) { " << endl;
+    cerr << "   n : " << n_ << " -> " << n << endl;
+    cerr << "  dt : " << dT_/n_ << " -> " << dT_/n << endl;
+    cerr << " CFL : " << CFL_ << " -> " << (n_*CFL_)/n << endl;
+    cerr << "}" << endl;
+    CFL_ *= Real(n_)/Real(n);
+    n_ = n;
   }
   return adjustment;
 }
@@ -247,7 +270,7 @@ NSIntegrator::NSIntegrator(FlowField& u, const ChebyCoeff& Ubase,
 
   // Alternating and SkewSymmetric require a 9d (3x3) tmp flowfield
   if (flags_.nonlinearity ==  Alternating || 
-      flags_.nonlinearity ==  _Alternating || 
+      flags_.nonlinearity ==  Alternating_ || 
       flags_.nonlinearity ==  Convection || 
       flags_.nonlinearity ==  Divergence || 
       flags_.nonlinearity ==  SkewSymmetric) 
@@ -686,6 +709,11 @@ void NSIntegrator::advance(FlowField& un, FlowField& qn, int nSteps) {
       //cout.form("%4.2f ", t_);
       cout.flush();
     }
+    else if (flags_.verbosity == PrintTicks) {
+      cout << '.';
+      //cout.form("%4.2f ", t_);
+      cout.flush();
+    }
   }
   //cout << "After integration..." << endl;
   //debugfunc(un);
@@ -845,7 +873,7 @@ DNSFlags::DNSFlags(MeanConstraint  constraint_,
   nonlinearity(nonlinearity_),
   dealiasing(dealiasing_),
   verbosity(verbosity_),
-  taucorrection(taucorrection)
+  taucorrection(taucorrection_)
 {
   if (dealias_y() && (nonlinearity != Rotational)) {
     cerr << "DNSFlags::DNSFlags: DealiasY and DealiasXYZ work only with\n";
@@ -876,3 +904,62 @@ int DNSFlags::numSubsteps() const {
   return rtn;
 }
 
+
+ostream& operator<<(ostream& os, Dealiasing d) {
+  string s;
+  switch(d) {
+  case NoDealiasing: s="NoDealiasing"; break;
+  case DealiasXZ: s="DealiasXZ"; break;
+  case DealiasY: s="DealiasY"; break;
+  case DealiasXYZ: s="DealiasXYZ"; break;
+  default: s="Invalid Dealiasing value: please submit bug report";
+  }
+  os << s;
+  return os;
+}
+
+ostream& operator<<(ostream& os, MeanConstraint m) {
+  string s;
+  switch(m) {
+  case PressureGradient: s="PressureGradient"; break;
+  case BulkVelocity: s="BulkVelocity"; break;
+  default: s="Invalid MeanConstraint value: please submit bug report";
+  }
+  os << s;
+  return os;
+}
+
+ostream& operator<<(ostream& os, TimeStepMethod t) {
+  string s;
+  switch(t) {
+  case CNAB2: s="CNAB2"; break;
+  case RK3: s="RK3"; break;
+  default: s="Invalid TimeStepMethod value: please submit bug report";
+  }
+  os << s;
+  return os;
+}
+ostream& operator<<(ostream& os, Verbosity v) {
+  string s;
+  switch(v) {
+  case Silent: s="Silent"; break;
+  case PrintTicks: s="PrintTicks"; break;
+  case PrintTime: s="PrintTime"; break;
+  case VerifyTauSolve: s="VerifyTauSolve"; break;
+  case PrintAll: s="PrintAll"; break;
+  default: s="Invalid Verbosity value: please submit bug report";
+  }
+  os << s;
+  return os;
+}
+
+ostream& operator<<(ostream& os, DNSFlags& flags) {
+  string s(", ");
+  string tau = (flags.taucorrection) ? "TauCorrection" : "NoTauCorrection";
+  os << flags.constraint << s << flags.timestepping << s << flags.nonlinearity
+     << flags.dealiasing << s << tau << s << flags.verbosity;
+  return os;
+}
+
+
+
