@@ -129,7 +129,7 @@ TauSolver::TauSolver(int kx, int kz, Real Lx, Real Lz, Real a, Real b,
   // Calculate the influence matrix.
 
   // Make some local aliases to temp storage, for readability
-  // This is not an efficiency issue, since TauSolvers are constructred once.
+  // This is not an efficiency issue, since TauSolvers are constructed once.
   ChebyCoeff dvplus_dy(N_, a_, b_, Spectral);
   ChebyCoeff dvminus_dy(N_, a_, b_, Spectral);
   ChebyCoeff zero(N_, a_, b_, Spectral);
@@ -235,23 +235,36 @@ void TauSolver::solve_P_and_v(ChebyCoeff& P, ChebyCoeff& v, const ChebyCoeff& r,
   if (!tauCorrection_) 
     return;
 
-  // Add up tau correction terms.
+  // Add up tau correction terms. Quotes are from Canuto & Hussaini pg 219
+  // My Nb is Canuto's N.
+  // My sigma1_Nb  is Canuto's sigma_{1m} for m=N
+  // My sigma1_Nb1 is Canuto's sigma_{1m} for m=N-1
+
+  // Set tmp = vyy;
   diff2(v,tmp);
+
+  // "define sigma_{1m} and sigma_{0m} for m = N-1, N as the tau 
+  // terms that must be added to the v-momentum eqns for (P1,v1) and 
+  // (P0,v0) for them to hold"
   Real sigma1_Nb  = lambda_*v[Nb_]   - nu_*tmp[Nb_]   - Ry[Nb_];
   Real sigma1_Nb1 = lambda_*v[Nb_-1] - nu_*tmp[Nb_-1] - Ry[Nb_-1];
   diff(P, tmp);  
   sigma1_Nb  += tmp[Nb_];
   sigma1_Nb1 += tmp[Nb_-1];
+
+  // "One can show that sigma_m = sigma_{1m}/(1-sigma_{0m}, m=N-1,N"
   sigmaNb  = sigma1_Nb/(1.0 - sigma0_Nb_);
   sigmaNb1 = sigma1_Nb1/(1.0 - sigma0_Nb1_);
+
+  // " and that ..."
   for (int i=0; i<=Nb_; ++i) {
     P[i]   += ((i%2 == 0) ? sigmaNb1 : sigmaNb) * P_0_[i];
     v[i]   += ((i%2 == 0) ? sigmaNb  : sigmaNb1) * v_0_[i];
   }
 
-#ifdef DEBUG
+  //#ifdef DEBUG
   //verify_P_and_v(P,v,r,Ry, sigmaNb1, sigmaNb, true);
-#endif
+  //#endif
 
   return;
 }
@@ -416,8 +429,8 @@ void TauSolver::solve(ComplexChebyCoeff& u, ComplexChebyCoeff& v,
 		      Real umean) const {
 
   // This function should only be called for kx==kz==0, since the enforcing 
-  // const velocity flux makes sense only for that case. Divergence is not a problem
-  // here, so solve everything via momentum. 
+  // const velocity flux makes sense only for that case. Divergence is not a 
+  // problem here, so solve everything via momentum. 
   assert(kx_==0 && kz_==0);
 
   ComplexChebyCoeff r(N_,a_,b_,Spectral);
@@ -578,6 +591,7 @@ Real TauSolver::verify(const ComplexChebyCoeff& u, const ComplexChebyCoeff& v,
   lerr = L2Dist(lhs, r);
   error += lerr;
   if (verbose) {
+    cerr << "really ..." << endl;
     cerr << "L2Norm(div R) == " << L2Norm(r) << endl;
     cerr << "tauDist(P'' - k^2 P, div R)   == " << terr << endl;
     cerr << " L2Dist(P'' - k^2 P, div R)   == " << lerr << endl;
@@ -627,15 +641,17 @@ Real TauSolver::verify(const ComplexChebyCoeff& u, const ComplexChebyCoeff& v,
   if (verbose) 
     cerr << "w(a),w(b) == " << wa << " " << wb << endl;
 
-  if (verbose)
-    cerr << "} TauSolver::verify(...)" << endl;
-  
   Real mean_error = norm2(Re(u.mean()) - umean);
+  error += mean_error;
   if (verbose)
     cerr << "norm2(u.mean() - umean) == " << mean_error << endl;
   else
     assert(mean_error < EPSILON);
   
+  if (verbose) {
+    cerr << "total verification error == " << error << endl;
+    cerr << "} TauSolver::verify(...)" << endl;
+  }
   return error;
 }
   
